AdviceInputs

Struct AdviceInputs 

pub struct AdviceInputs {
    pub stack: Vec<Felt>,
    pub map: AdviceMap,
    pub store: MerkleStore,
}
Inputs container to initialize advice provider for the execution of Miden VM programs.

The program may request nondeterministic advice inputs from the prover. These inputs are secret inputs. This means that the prover does not need to share them with the verifier.

There are three types of advice inputs:

  1. Single advice stack which can contain any number of elements.
  2. Key-mapped element lists which can be pushed onto the advice stack.
  3. Merkle store, which is used to provide nondeterministic inputs for instructions that operates with Merkle trees.

Fields

stack: Vec<Felt>map: AdviceMapstore: MerkleStore

Implementations

Source

impl AdviceInputs

pub fn with_stack_values<I>(self, iter: I) -> Result<Self, InputError>
where I: IntoIterator<Item = u64>,

Attempts to extend the stack values with the given sequence of integers, returning an error if any of the numbers fails while converting to an element [Felt].

pub fn with_stack<I>(self, iter: I) -> Self
where I: IntoIterator<Item = Felt>,

Extends the stack with the given elements.

pub fn with_map<I>(self, iter: I) -> Self
where I: IntoIterator<Item = (Word, Vec<Felt>)>,

Extends the map of values with the given argument, replacing previously inserted items.

pub fn with_merkle_store(self, store: MerkleStore) -> Self

Replaces the MerkleStore with the provided argument.

pub fn extend(&mut self, other: Self)

Extends the contents of this instance with the contents of the other instance.