Struct PublicKey
pub struct PublicKey { /* private fields */ }Expand description
Public key for ECDSA signature verification over secp256k1 curve.
Implementations
impl PublicKey
impl PublicKey
pub fn to_commitment(&self) -> Word
pub fn to_commitment(&self) -> Word
Returns a commitment to the public key using the Poseidon2 hash function.
The commitment is computed by first converting the public key to field elements (4 bytes per element), and then computing a sequential hash of the elements.
pub fn verify(&self, message: Word, signature: &Signature) -> bool
pub fn verify(&self, message: Word, signature: &Signature) -> bool
Verifies a signature against this public key and message.
pub fn verify_prehash(
&self,
message_digest: [u8; 32],
signature: &Signature,
) -> bool
pub fn verify_prehash( &self, message_digest: [u8; 32], signature: &Signature, ) -> bool
Verifies a signature against this public key and pre-hashed message.
pub fn recover_from(
message: Word,
signature: &Signature,
) -> Result<PublicKey, PublicKeyError>
pub fn recover_from( message: Word, signature: &Signature, ) -> Result<PublicKey, PublicKeyError>
Recovers from the signature the public key associated to the secret key used to sign the message.