pub struct CallNode { /* private fields */ }Expand description
A Call node describes a function call such that the callee is executed in a different execution context from the currently executing code.
A call node can be of two types:
- A simple call: the callee is executed in the new user context.
- A syscall: the callee is executed in the root context.
Implementations
Sourceimpl CallNode
Constants
impl CallNode
Constants
Sourcepub const CALL_DOMAIN: Felt
pub const CALL_DOMAIN: Felt
The domain of the call block (used for control block hashing).
Sourcepub const SYSCALL_DOMAIN: Felt
pub const SYSCALL_DOMAIN: Felt
The domain of the syscall block (used for control block hashing).