pub struct LoopNode { /* private fields */ }Expand description
A Loop node defines condition-controlled iterative execution. When the VM encounters a Loop node, it will keep executing the body of the loop as long as the top of the stack is `1``.
The loop is exited when at the end of executing the loop body the top of the stack is 0``. If the top of the stack is neither 0nor1` when the condition is checked, the execution
fails.
Implementations