pub enum Decorator {
Debug(DebugOptions),
Trace(u32),
}Expand description
A set of decorators which can be executed by the VM.
Executing a decorator does not affect the state of the main VM components such as operand stack and memory.
Executing decorators does not advance the VM clock. As such, many decorators can be executed in a single VM cycle.
Variants
Debug(DebugOptions)
Prints out information about the state of the VM based on the specified options. This decorator is executed only in debug mode.
Trace(u32)
Emits a trace to the host.
Implementations
Sourceimpl Decorator
impl Decorator
pub fn fingerprint(&self) -> DecoratorFingerprint