Module proof

Module proof 

Structs

ExecutionProof
A proof of correct execution of Miden VM.
InvalidHashFunctionError
Error type for invalid hash function strings.
StarkProof
A serialized STARK proof and the hash function used during proof generation.

Enums

DeferredProof
Proof material for the precompile claims associated with an execution proof.
HashFunction
A hash function used during STARK proof generation.