pub struct ColMatrix<E> { /* private fields */ }Implementations
Sourceimpl<E: Clone + Copy> ColMatrix<E>
impl<E: Clone + Copy> ColMatrix<E>
Sourcepub fn get(&self, col_idx: usize, row_idx: usize) -> E
pub fn get(&self, col_idx: usize, row_idx: usize) -> E
Returns the element located at the specified column and row indexes in this matrix.
Panics
Panics if either col_idx or row_idx are out of bounds for this matrix.
Sourcepub fn get_column(&self, col_idx: usize) -> &[E]
pub fn get_column(&self, col_idx: usize) -> &[E]
Returns a reference to the column at the specified index.
Sourcepub fn get_column_mut(&mut self, col_idx: usize) -> &mut [E]
pub fn get_column_mut(&mut self, col_idx: usize) -> &mut [E]
Returns a reference to the column at the specified index.
Sourcepub fn columns(&self) -> impl Iterator<Item = &[E]>
pub fn columns(&self) -> impl Iterator<Item = &[E]>
Returns an iterator over all columns in this matrix.
Sourcepub fn read_row_into(&self, row_idx: usize, row: &mut [E])
pub fn read_row_into(&self, row_idx: usize, row: &mut [E])
Copies values of all columns at the specified row into the specified row slice.
Panics
Panics if row_idx is out of bounds for this matrix.
Sourcepub fn update_row(&mut self, row_idx: usize, row: &[E])
pub fn update_row(&mut self, row_idx: usize, row: &[E])
Updates a row in this matrix at the specified index to the provided data.
Panics
Panics if row_idx is out of bounds for this matrix.
Sourcepub fn merge_column(&mut self, column: Vec<E>)
pub fn merge_column(&mut self, column: Vec<E>)
Merges a column to the end of the matrix provided its length matches the matrix.
Panics
Panics if the column has a different length to other columns in the matrix.
Sourcepub fn remove_column(&mut self, index: usize) -> Vec<E>
pub fn remove_column(&mut self, index: usize) -> Vec<E>