Function flatten
pub fn flatten(doc: Document) -> DocumentExpand description
Use the leftmost option of every choice in the given document.
If the given document upholds the expectation that none of the leftmost choices contain newlines, then this combinator has the effect of displaying all choices on one line.