pub struct ExecutionProofCompatibility { /* private fields */ }Expand description
The transport format and recursive verifier roots declared by an execution proof.
Verifier roots are listed in chronological order, with the newest root last. Root order does not affect compatibility checks.
Implementations
Sourceimpl ExecutionProofCompatibility
impl ExecutionProofCompatibility
Sourcepub fn new(
vm_verifier_roots: Vec<Word>,
pvm_verifier_roots: Vec<Word>,
) -> Result<Self, ExecutionProofCompatibilityError>
pub fn new( vm_verifier_roots: Vec<Word>, pvm_verifier_roots: Vec<Word>, ) -> Result<Self, ExecutionProofCompatibilityError>
Creates a proof compatibility declaration for format 1.
Errors
Returns an error if either verifier root list contains duplicates.
Sourcepub fn current() -> Self
pub fn current() -> Self
Returns the compatibility declared by proofs produced by the current prover.
Sourcepub fn vm_verifier_roots(&self) -> &[Word]
pub fn vm_verifier_roots(&self) -> &[Word]
Returns the VM verifier roots which can be used to verify this proof.
The roots are unique and listed in chronological order with the most recent verifier listed last.
Sourcepub fn pvm_verifier_roots(&self) -> &[Word]
pub fn pvm_verifier_roots(&self) -> &[Word]
Returns the precompile VM verifier roots which can be used to verify the precompile proof associated with this execution proof, if any.
The roots are unique and listed in chronological order with the most recent verifier listed last.